==> Mongeasy-0.1.4-py3-none-any.whl: mongeasy/exceptions.py <==
"""
This module contains custom Mongeasy exceptions.

MIT License

Copyright (c) 2023 Joakim Wassberg

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation 
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, 
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom 
the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE 
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""


class MongEasyException(Exception):
    """
    Base exception class
    """


class MongEasyDBConnectionError(MongEasyException):
    """
    Database initialization exceptions
    """


class MongEasyDBCollectionError(MongEasyException):
    """
    Collection exceptions
    """


class MongEasyDBDocumentError(MongEasyException):
    """
    Document exceptions
    """


class MongEasyFieldError(MongEasyException):
    """
    Field exceptions
    """
    
class MongEasyValidationException(MongEasyException):
    """
    Validation exceptions
    """
    
class MongEasyIndexException(MongEasyException):
    """
    Index exceptions
    """

==> Mongeasy-0.1.8-py3-none-any.whl: mongeasy/exceptions.py <==
"""
This module contains custom Mongeasy exceptions.

MIT License

Copyright (c) 2023 Joakim Wassberg

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation 
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, 
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom 
the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE 
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""


class MongeasyException(Exception):
    """
    Base exception class
    """


class MongeasyDBConnectionError(MongeasyException):
    """
    Database initialization exceptions
    """


class MongeasyDBCollectionError(MongeasyException):
    """
    Collection exceptions
    """


class MongeasyDBDocumentError(MongeasyException):
    """
    Document exceptions
    """


class MongeasyFieldError(MongeasyException):
    """
    Field exceptions
    """
    
class MongeasyValidationException(MongeasyException):
    """
    Validation exceptions
    """
    
class MongeasyIndexException(MongeasyException):
    """
    Index exceptions
    """
